@@ -47,7 +47,7 @@ function initiate(){
 
 
 function ready(data) {
-    if(!data.mostrar_cursor){
+    if(!data.show_cursor){
         $("html").css("cursor", "none");
     }
 	set_locale(data.locale);
@@ -142,7 +142,6 @@ $(document).ready(function(){
 	ctx.lineWidth = 10.0;
 
 	imd = ctx.getImageData(0, 0, 100, 100);
-
 	$(document).mousedown(function(e){
 		if (state == 'init'){
 			hide_init_msg();
@@ -175,7 +174,7 @@ $(document).ready(function(){
 			send('click', click_pos);
 			show_calibration_msg();
 		}
-		else if ((state == 'calibrating')){
+		else if (state == 'calibrating'){
 		  	ctx.clearRect(0, 0, bg.width, bg.height);
 		  	window.clearInterval(interval);
 		  	if (step < 100){
